/*
 * Attach an Adafruit Motor Shield to the Arduino Uno/Mega.
 * In addition to powering the RC Receiver (with GND and 5V), connect 
 * one of the RC Receiver's signal pins to the Arduino's digital pin 2.
 * The duration of the high RC pulse will be used to control a motor 
 * attached to Motor Shield motor port 1.
 * 
 * Author: David Wang, NuVu Studio
 */
#include <RCPulseIn.h>
#include <EnableInterrupt.h>
#include <Wire.h>
#include <Adafruit_MotorShield.h>

// Create the motor shield object with the default I2C address
Adafruit_MotorShield AFMS = Adafruit_MotorShield(); 
// Or, create it with a different I2C address (say for stacking)
// Adafruit_MotorShield AFMS = Adafruit_MotorShield(0x61); 

// Select which 'port' M1, M2, M3 or M4. In this case, M1
Adafruit_DCMotor *motor1 = AFMS.getMotor(1);
// You can also make another motor on port M2
//Adafruit_DCMotor *motor2 = AFMS.getMotor(2);


// define an interrupt for digital pin 2.
// that will need to read an RC pulse train.
defineRC(2);

void setup() {
  // setup Serial communication, for the Arduino console.
  Serial.begin(9600);
  // setup the RC interrupt for digital pin 2.
  // (You need to use "defineRC(pin)" for each pin, see above.)
  setupRC(2);
  // Start communication with the motor shield.
  AFMS.begin();

}

void loop() {
  // Use the function "readRC(pinNumber)" to read the duration  
  // of the high voltage pulse to digital pin 2.
  // (You need to use "defineRC(pin)" and "setupRC(pin)" for each pin, see above.)
  Serial.print(readRC(2));
  Serial.println();

  // Converts the RC signal, which ranges in value from ~1000 to ~2000, 
  // into the range -255 to 255, which the motor understands as speed settings.
  // Since RC controllers don't always return to dead center, we use a 
  // special "deadband" map function so the center 200 values will map to 0.
  int motor1Speed = deadbandMap(readRC(2),1000,200,2000,-255,0,255);
  Serial.println(motor1Speed);
  runMotor(motor1,motor1Speed);

}

/*
 * Runs an Adafruit Motor for speeds from -255 (reverse) to 0 (brake) to 255 (forward).
 */
void runMotor(Adafruit_DCMotor *myMotor, int spd){
  if(spd>0){
    myMotor->run(FORWARD);
    myMotor->setSpeed(spd);
  }else if(spd<0){
    myMotor->run(BACKWARD);
    myMotor->setSpeed(-1*spd);
  }else{
    myMotor->run(BRAKE);
    myMotor->setSpeed(0);
  }
}